# Example Skill

This is an example skill for demonstration and testing purposes.

## Description

This skill provides example context and instructions for testing the ClaudeCodeWithSkills agent.

## Usage

Use this skill when you need to demonstrate or test skill loading functionality in Harbor evaluations.

## Instructions

When this skill is loaded, Claude Code will have access to this context and can use it to inform responses during evaluations.
